@@ -2,19 +2,16 @@
 # -----------------------------------------------------------------------------
 #
 #  Nes by Skriptke
-#  Copyright 2009 - 2010 Enrique F. Castañón Barbero
+#  Copyright 2009 - 2010 Enrique F. Castañón
 #  Licensed under the GNU GPL.
 #
-#  CPAN:
-#  http://search.cpan.org/dist/Nes/
-#
 #  Sample:
 #  http://nes.sourceforge.net/
 #
 #  Repository:
 #  http://github.com/Skriptke/nes
 # 
-#  Version 1.00
+#  Version 1.00_01
 #
 #  Nes.pm
 #
@@ -22,11 +19,9 @@
 
 use strict;
 #use warnings;
+#no warnings 'uninitialized';
 
-# cgi environment no defined in command line
-no warnings 'uninitialized';
-
-our $VERSION          = '1.00';
+our $VERSION          = '1.00_01';
 our $CRLF             = "\015\012";
 our $MAX_INTERACTIONS = 500;
 our $MOD_PERL         = $ENV{'MOD_PERL'} || 0;
